@@ -125,7 +125,8 @@ class Application:
 
     def _configure_exception_handlers(self, app: FastAPI) -> None:
         """Register common exception handlers with the app."""
-        from starlette.exceptions import HTTPException as StarletteHTTPException
+        from starlette.exceptions import \
+            HTTPException as StarletteHTTPException
 
         @app.exception_handler(StarletteHTTPException)
         async def _http_exception_handler(
