@@ -1,3 +1,5 @@
+"""Validation exception handler middleware for FastAPI."""
+
 import json
 
 from fastapi.exceptions import ValidationException
@@ -14,7 +16,7 @@ async def validation_exception_handler(_, exc: ValidationException) -> JSONRespo
         location = " -> ".join([str(loc_item) for loc_item in error["loc"]])
         try:
             input_data = ", input: " + json.dumps(error["input"], default=str)
-        except:
+        except Exception:
             input_data = ""
 
         error = (
