@@ -1,4 +1,4 @@
-from typing import List, Any, Generator
+from typing import Any, Generator, List
 
 __all__ = (
     "chunk_list",
