@@ -2,8 +2,8 @@ from datetime import datetime
 from enum import Enum
 from typing import Any
 
-from sqlalchemy import (ARRAY, Text, and_, array, cast, func, literal, or_,
-                        select)
+from sqlalchemy import Text, and_, cast, func, literal, or_, select
+from sqlalchemy.dialects.postgresql import array, ARRAY
 
 __all__ = ("make_condition",)
 
