@@ -19,7 +19,7 @@ def make_selected_filters(
         ):
             continue
 
-        if filter_item["type"] == "select":
+        if filter_item["type"] in {"select", "select_array"}:
             for data in selected_data:
                 enum = filter_item.get("enum")
                 labels = filter_item.get("labels", {})
