@@ -35,5 +35,13 @@ class RedisConfig:
         self._config_data["redis_ssl"] = ssl
         return self
 
+    def set_redis_max_connections(self, redis_max_connections: int):
+        self._config_data["redis_max_connections"] = redis_max_connections
+        return self
+
+    def set_redis_socket_timeout(self, redis_socket_timeout: int):
+        self._config_data["redis_socket_timeout"] = redis_socket_timeout
+        return self
+
     def get(self, key: str, default: Any = None):
         return self._config_data.get(key, default)
